#
# spec file for package qterminal
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qterminal
Version:        0.7.0
Release:        3.4
Summary:        A Qt-based terminal emulator
License:        GPL-2.0
Group:          System/X11/Terminals
Url:            http://lxqt.org
Source0:        https://downloads.lxqt.org/%{name}/%{version}/%{name}-%{version}.tar.xz
Source1:        https://downloads.lxqt.org/%{name}/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  pkgconfig
BuildRequires:  qtermwidget-qt5-devel >= %{version}
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(lxqt)
Requires(post): desktop-file-utils
Requires(pre):  desktop-file-utils
Recommends:     %{name}-lang

%description
The lightweight Qt terminal emulator.

%lang_package

%prep
%setup -q

%build
%cmake \
    -DUSE_QT5=ON \
    -DUSE_SYSTEM_QXT=OFF \
	-DPULL_TRANSLATIONS=No
make %{?_smp_mflags}

%install
%cmake_install

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc AUTHORS LICENSE README.md CONTRIBUTING*
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}_drop.desktop
%dir %{_datadir}/appdata
%{_datadir}/appdata/qterminal.appdata.xml
%{_datadir}/icons/hicolor/64x64/apps/qterminal.png

%changelog
* Sun Sep 25 2016 mvetter@suse.com
- Update to 0.7.0:
  * Bump version to 0.7.0 (#262)
  * Update README.md
  * Collapse splitter hierarchies containing a single terminal (#254)
  * Make qterminal.appdata.xml valid (#257)
  * Add config option for changing window's title/icon
  * Add support for automatic title & icon modification
  * Delete Properties instance on exit (#239)
  * Fix compilation warning related to QXmlStreamReader (#247)
  * Set the desktopFileName property
  * Fix typo in the conditional expression
  * Add location for custom color schemes (#234)
  * CMake Support changes (#237)
  * Add keyboard cursor shape setting (#228)
  * made the .pro file work on openSUSE; #229 (#232)
  * Fix renaming a tab from the menu
  * Make the rename current session shortcut work and configurable
  * build: Use external translations
  * ts-files removal (#222)
  * Add pt_BR (Brazilian Portuguese) translation (#215)
  * Merge pull request #214 from f2404/212_collapse_segfault_fix
  * Remove noisy qDebug()
  * Fix jumbled prompt
  * Add Greek (el) translation
  * Missing equal symbol for xml template
  * Delete MainWindow on exit
  * Link to the current github projects and trackers
  * Apply context menu to the tab that it was opened over
  * Close tabs in reverse order
  * Eliminate memory leaks by closing tabs on exit
  * Russian translation update
  * Fix menubar transparency
  * Fix default settings width
  * Fix bookmarks widget transparency
  * Use the same icon for dropdown and regular terminal
  * Fix license file
  * Improve README and use markdown
  * Fixed button focus in close confirmation (resolves #179).
  * Updated german translation.
  * Fix Simplified Chinese(zh_CN)
  * Update japanese translation
  * Add Japanese translation to *.desktop
  * fixed #174 XDG_CONFIG_DIRS support - read system wide QSettings
  * Fix license issues within qterminal
  * Add chinese translation
  * Require Qt 5.2 or higher
  * fix private header dependency for X11 global shortcuts
  * fix searching for Qt5 private headers
  * make only terminal widget transparent, not the parent window
  * Fix japanese translation
  * Russian translation update
  * Add Japanese translation
  * fixed #160 FTBFS as of commit 4967123
  * Fixes for Portuguese language
  * Fixes missing App Window icon
  * Hungarian translation added
  * Update qterminal_tr.ts
  * Create qterminal_tr.ts
  * do not overwrite settings in migrateSettings
  * remove fullscreen patch
  * migrateSettings add size and pos and rm geometry
  * split geometry into size and position
  * define saveGeomOnExit in properties.h
  * add save geometry on exit
  * Add Alt-<letter> shortcuts to all menu items.
  * Make sure no settings are overwritten in migrateSettings().
  * Update index property of tabs when tabs are moved by drag-and-drop.
  * Update german translation.
  * Corrected terminology in settings (transparency vs. opacity). Now transparency instead of opacity is used in the whole application consistently.
  * Migrate AlwaysShowTabs-setting.
  * Move migrateSettings()-method to Properties-class and call it *before* loadSettings().
  * Update version number in settings.
  * Renamed always show tabs setting.
  * Portuguese update
  * Add instructions to disable system qxt when building with Qt5.
  * Changed position of font button in settings.
  * Changed layout of font-setting to better fit to the other settings in the widget.
  * Appdata file for QTerminal (resolves #60).
  * Add view-menu actions to mainwindow, to make them available when menu bar is hidden.
  * Add fullscreen mode.
  * Ignore user-specific project files of QtCreator.
  * Resolves #115: Store Actions of 'View'-menu in properties too and enable shorctus for them.
  * Set shortcuts for 'Preferences...' and 'Quit' from settings on startup.
  * Fixed #83: Add menu actions to main window.
  * Fixed #93: Add 'Toggle Menu' and 'Preferences...' to context menu.
  * Use GNUInstallDirs in CMakeLists.txt to stop hardcoding paths
  * Make the left column expandable to get more space for translated text.
  * Updated german translation
  * Remove empty file
  * Remove unnecessarily noisy qDebug calls
  * Portuguese update
  * Add Portuguese translation
  * Update Russian translation
  * slightly naive "layout/preset" implementation
  * fixed build for Qt4 and Qt5.x < 5.2
  * Rework settings window
  * Fixed translation (added tr() for some combo boxes in properties dialog).
- Add keyring
- Remove preferences_context_menu.patch: upstreamed
* Mon Aug  8 2016 mvetter@suse.com
- Adapt qtermwidget name change
  See: https://build.opensuse.org/request/show/397609
* Tue Mar  8 2016 mvetter@suse.com
- Adding: preferences_context_menu.patch
  Without this it's possible to disable the menu bar with
  no way to bring it back.
* Sat Mar  5 2016 avvissu@yandex.ru
- Initial release
